package com.diagbot.web;


import com.diagbot.annotation.SysLogger;
import com.diagbot.client.MedAppealInfoServiceClient;
import com.diagbot.dto.GetAppealInfoDTO;
import com.diagbot.dto.GetReviewerDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.Response;
import com.diagbot.entity.SysUser;
import com.diagbot.entity.WorkFlowInfo;
import com.diagbot.facade.SysHospitalSetFacade;
import com.diagbot.util.SysJwtUtil;
import com.diagbot.util.SysUserUtils;
import com.diagbot.vo.AddAppealInfoVO;
import com.diagbot.vo.CancelAppealInfoVO;
import com.diagbot.vo.GetAppealInfoVO;
import com.diagbot.vo.GetAppealOperationTypeVO;
import com.diagbot.vo.GetReviewerVO;
import com.diagbot.vo.MedAppealInfoVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import springfox.documentation.annotations.ApiIgnore;

import javax.validation.Valid;
import java.util.List;
import java.util.Map;


/**
 * <p>
 * 申诉审核 前端控制器
 * </p>
 *
 * @author wangfeng
 * @since 2020-07-06
 */
@RestController
@RequestMapping("/qc/appealInfo")
@Api(value = "申诉审核API", tags = { "申诉审核API" })
@SuppressWarnings("unchecked")
public class MedAppealInfoController {

    @Autowired
    MedAppealInfoServiceClient medAppealInfoServiceClient;

    @Autowired
    SysHospitalSetFacade sysHospitalSetFacade;

    @ApiOperation(value = "获取申诉任务接口[by:songxl]",
            notes = "获取申诉任务接口")
    @PostMapping("/getWorkById")
    @SysLogger("getWorkById")
    public RespDTO<MedAppealInfoVO> getWorkById(@RequestBody MedAppealInfoVO medAppealInfoVO) {
        Response<WorkFlowInfo> res = medAppealInfoServiceClient.getWorkById(medAppealInfoVO);
        return RespDTO.onSuc(res.getData());
    }
    @ApiOperation(value = "申诉[by:songxl]",
            notes = "申诉")
    @PostMapping("/addAppealInfo")
    @Transactional
    public RespDTO<Boolean> addAppealInfo(@RequestBody @Valid AddAppealInfoVO addAppealInfoVO) {
        addAppealInfoVO.setHospitalId(Long.parseLong(SysUserUtils.getCurrentHospitalID()));
        addAppealInfoVO.setClaimantId(Long.parseLong(SysUserUtils.getCurrentPrincipleID()));
        return medAppealInfoServiceClient.addAppealInfo(addAppealInfoVO);
    }
    @ApiOperation(value = "获取审核人[by:songxl]",
            notes = "获取审核人")
    @PostMapping("/getReviewer")
    public RespDTO<List<GetReviewerDTO>> getReviewer(@RequestBody GetReviewerVO getReviewerVO) {
        getReviewerVO.setClaimantId(Long.parseLong(SysUserUtils.getCurrentPrincipleID()));
        //申诉人是否包含自身开关
        String flag = sysHospitalSetFacade.getValue(Long.parseLong(SysUserUtils.getCurrentHospitalID()),"self_flag");
        if(StringUtils.isNotEmpty(flag)){
            getReviewerVO.setSelfFlag(Boolean.parseBoolean(flag));
        }
        return medAppealInfoServiceClient.getReviewer(getReviewerVO);
    }

    @ApiOperation(value = "再次申诉获取操作类型[by:songxl]",
            notes = "再次申诉获取操作类型")
    @PostMapping("/getAppealOperationType")
    public RespDTO<Map<String, String>> getAppealOperationType(@RequestBody @Valid GetAppealOperationTypeVO getAppealOperationTypeVO) {
        return medAppealInfoServiceClient.getAppealOperationType(getAppealOperationTypeVO);
    }

    @ApiOperation(value = "撤回申诉[by:songxl]",
            notes = "撤回申诉")
    @PostMapping("/cancelAppealInfo")
    @Transactional
    public RespDTO<Boolean> cancelAppealInfo(@RequestBody @Valid CancelAppealInfoVO cancelAppealInfoVO) {
        return medAppealInfoServiceClient.cancelAppealInfo(cancelAppealInfoVO);
    }

    @ApiOperation(value = "申诉记录详情-查看[by:songxl]",
            notes = "申诉记录详情-查看")
    @PostMapping("/getAppealInfo")
    public RespDTO<GetAppealInfoDTO> getAppealInfo(@RequestBody GetAppealInfoVO getAppealInfoVO) {
        return medAppealInfoServiceClient.getAppealInfo(getAppealInfoVO);
    }

}
